==> script.module.resolveurl-5.1.36.zip: script.module.resolveurl-master/lib/resolveurl/plugins/streamsb.py <==
"""
    Plugin for ResolveUrl
    Copyright (C) 2020 gujal
    Copyright (C) 2020 groggyegg

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
"""

from resolveurl.plugins.__resolve_generic__ import ResolveGeneric
from resolveurl.plugins.lib import helpers


class StreamSBResolver(ResolveGeneric):
    name = "streamsb"
    domains = ["sbembed.com", "sbplay.org", "sbvideo.net", "streamsb.net"]
    pattern = r'(?://|\.)((?:stream)?sb(?:embed|play|video)?\.(?:com|net|org))/(?:embed-|e|play)/?([0-9a-zA-Z]+)'

    def get_media_url(self, host, media_id):
        return helpers.get_media_url(self.get_url(host, media_id),
                                     patterns=[r'''sources\s*:\s*\["(?P<url>[^"]+)''',
                                               r'''(?:file|src):\s*"(?P<url>[^"]+)'''],
                                     generic_patterns=False,
                                     result_blacklist=['dl', '.srt', '.vtt'],
                                     referer=False)

    def get_url(self, host, media_id):
        return self._default_get_url(host, media_id, template='https://{host}/play/{media_id}')

==> script.module.resolveurl-5.1.37.zip: script.module.resolveurl-master/lib/resolveurl/plugins/streamsb.py <==
"""
    Plugin for ResolveUrl
    Copyright (C) 2020 gujal
    Copyright (C) 2020 groggyegg

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
"""

from resolveurl.plugins.__resolve_generic__ import ResolveGeneric
from resolveurl.plugins.lib import helpers


class StreamSBResolver(ResolveGeneric):
    name = "streamsb"
    domains = ["sbembed.com", "sbembed1.com", "sbplay.org", "sbvideo.net", "streamsb.net", "sbplay.one"]
    pattern = r'(?://|\.)((?:stream)?sb(?:embed\d?|play|video)?\.(?:com|net|org|one))/(?:embed-|e|play)/?([0-9a-zA-Z]+)'

    def get_media_url(self, host, media_id):
        return helpers.get_media_url(self.get_url(host, media_id),
                                     patterns=[r'''sources\s*:\s*\["(?P<url>[^"]+)''',
                                               r'''(?:file|src):\s*"(?P<url>[^"]+)'''],
                                     generic_patterns=False,
                                     result_blacklist=['dl', '.srt', '.vtt'],
                                     referer=False)

    def get_url(self, host, media_id):
        return self._default_get_url(host, media_id, template='https://{host}/play/{media_id}')
